@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mu4e-column-faces" "1.2.1"
+(define-package "mu4e-column-faces" "20250205.2118"
   "Faces for individual mu4e columns."
   '((emacs "25.3"))
   :url "https://github.com/Alexander-Miller/mu4e-column-faces"
-  :commit "1bbb646ea07deb1bd2daa4c6eb36e0f65aac40b0"
-  :revdesc "1bbb646ea07d"
+  :commit "b3586a9bf61f0cddd8a9f4cb214458f13d37955a"
+  :revdesc "b3586a9bf61f"
   :authors '(("Alexander Miller" . "alexanderm@web.de"))
   :maintainers '(("Alexander Miller" . "alexanderm@web.de")))
